{% extends "admin/login.html" %}
{% load i18n static %}

{% block extrastyle %}
  {{ block.super }}
  <style>
    .form-row > input {
      padding: 8px;
      width: 100%;
      box-sizing: border-box;
    }
  </style>
{% endblock %}

{% block content %}
  {% if form.errors and not form.non_field_errors %}
  <p class="errornote">
    {% if form.errors.items|length == 1 %}{% trans "Please correct the error below." %}{% else %}{% trans "Please correct the errors below." %}{% endif %}
  </p>
  {% endif %}

  {% if form.non_field_errors %}
    {% for error in form.non_field_errors %}
      <p class="errornote">
          {{ error }}
      </p>
    {% endfor %}
  {% endif %}

  <div id="content-main">

  {% if user.is_authenticated %}
    <p class="errornote">
    {% blocktrans trimmed %}
        You are authenticated as {{ username }}, but are not authorized to
        access this page. Would you like to login to a different account?
    {% endblocktrans %}
    </p>
  {% endif %}

  <form action="{{ app_path }}" method="post" id="login-form">{% csrf_token %}
    {% for field in form %}
      <div class="form-row">
        {{ field.errors }}
        {{ field.label_tag }} {{ field }}
      </div>
    {% endfor %}

    {% url 'admin_password_reset' as password_reset_url %}

    {% if password_reset_url %}
      <div class="password-reset-link">
        <a href="{{ password_reset_url }}">{% trans 'Forgotten your password or username?' %}</a>
      </div>
    {% endif %}

    <div class="submit-row">
      <label>&nbsp;</label><input type="submit" value="{% trans 'Log in' %}">
    </div>
  </form>

  </div>
{% endblock %}