from swap_user.to_email_otp.base_managers import BaseEmailOTPUserManager


class EmailOTPUserManager(BaseEmailOTPUserManager):
    """
    Concrete implementation of manager for EmailOTPUser.
    """

    pass
